<?php

namespace Drupal\cleantalk\Service;

use Cleantalk\Common\API as CleantalkAPI;

class UserChecker
{
    
    public function checkUsers($offset = 0, $limit = 100)
    {
        $ct_authkey = trim(\Drupal::config('cleantalk.settings')->get('cleantalk_authkey'));

        if (!$ct_authkey) {
            return array(
                'error' => 'invalid_apy_key',
                'error_message' => 'Invalid apikey'
            );
        }
        
        $user_data = new UserData();
        $users = $user_data->getUsersFromFieldData($offset, $limit);
        
        if (!$users) {
            return array(
                'error' => 'no_users_found',
                'error_message' => 'No users found'
            );
        }
        
        // collecting user emails
        $user_emails = array();
        foreach ($users as $user) {
            if ($user->mail) {
                $user_emails[] = $user->mail;
            }
        }
        
        // Send query to API
        $result = CleantalkAPI::method__spam_check_cms($ct_authkey, $user_emails);

        if (isset($result['error_message'])) {
            return array(
                'error' => 'error_api',
                'error_message' => $result['error_message']
            );
        }

        // collecting spammer emails
        $spammers_emails = array();
        foreach ($result as $key => $value) {
            if (isset($value['appears']) && $value['appears'] == '1') {
                $spammers_emails[] = $key;
            }
        }
        
        $spammers = array();
        if ($spammers_emails) {
            foreach ($users as $user) {
                if (in_array($user->mail, $spammers_emails)) {
                    $spammers[] = array(
                        $user->uid,
                        'cleantalk',
                        'spammer',
                        '1'
                    );
                }
            }
        }

        if ($spammers) {
            $user_data->insertSpammers($spammers);
        }

        $result = array(
            'success' => 'ok',
            'count_spammers' => count($spammers),
            'last_query' => 0
        );
        
        if (count($users) < $limit || count($users) === 0) {
            $result['last_query'] = 1;
        }
        
        return $result;
    }
}